Learn R Programming

tseriesChaos (version 0.1-7)

mutual: Average Mutual Information

Description

Estimates the average mutual information index (ami) of a given time series for a specified number of lags

Usage

mutual(series, partitions = 16, lag.max = 20, plot=TRUE, ...)

Arguments

series
time series
partitions
number of bins
lag.max
largest lag
plot
logical. If 'TRUE' (the default) the ami is plotted
...
further arguments to be passed to the plot method

Value

  • An object of class "ami", which is a vector containing the estimated mutual information index for each lag between 0 and lag.max.

Details

Estimates the mutual information index for a specified number of lags. The joint probability distribution function is estimated with a simple bi-dimensional density histogram.

References

Hegger, R., Kantz, H., Schreiber, T., Practical implementation of nonlinear time series methods: The TISEAN package; CHAOS 9, 413-435 (1999)

Examples

Run this code
mutual(lorenz.ts)

Run the code above in your browser using DataLab