Description
Recurrence plotUsage
recurr(series, m, d, start.time=start(series), end.time=end(series), ...)
Arguments
start.time
starting time window (in time units)
end.time
ending time window (in time units)
...
further parameters to be passed to filled.contour
warning
Be awared that number of distances to store goes as n^2, where n = length(window(series, start=start.time, end=end.time))!Details
Produces the recurrence plot, as proposed by Eckmann et al. (1987).
White is maximum distance, black is minimum.References
Eckmann J.P., Oliffson Kamphorst S. and Ruelle D., Recurrence plots of dynamical systems, Europhys. Lett., volume 4, 973 (1987)Examples
Run this coderecurr(lorenz.ts, m=3, d=2, start.time=15, end.time=20)
Run the code above in your browser using DataLab